aboutsummaryrefslogtreecommitdiff
path: root/cros_utils
diff options
context:
space:
mode:
authorCaroline Tice <cmtice@google.com>2020-03-01 10:57:35 -0800
committerCaroline Tice <cmtice@chromium.org>2020-03-02 05:43:13 +0000
commit39d3c174860e4d68cca670338d069b99a9d1dde1 (patch)
tree7fe6f0023d9f455b30c54fa27dc5c992ad8dedc2 /cros_utils
parent26caa2f10035811150a11bb8871a2da1f593cf2b (diff)
downloadtoolchain-utils-39d3c174860e4d68cca670338d069b99a9d1dde1.tar.gz
toolchain-utils: Increase buildbot timeout to 15 hours.
Our nightly performance tryjobs are consistently taking more than 12 hours to complete, and our script is timing out. This CL increases the timeout limit to 14 hours. BUG=chromium:1057137 TEST=None Change-Id: Ief6bdb51f35d62ed6ad405a3f7369e58411ce9a5 Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/third_party/toolchain-utils/+/2082174 Tested-by: Caroline Tice <cmtice@chromium.org> Commit-Queue: Caroline Tice <cmtice@chromium.org> Reviewed-by: George Burgess <gbiv@chromium.org>
Diffstat (limited to 'cros_utils')
-rw-r--r--cros_utils/buildbot_utils.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/cros_utils/buildbot_utils.py b/cros_utils/buildbot_utils.py
index 428433db..859e0134 100644
--- a/cros_utils/buildbot_utils.py
+++ b/cros_utils/buildbot_utils.py
@@ -21,8 +21,8 @@ INITIAL_SLEEP_TIME = 7200 # 2 hours; wait time before polling buildbot.
SLEEP_TIME = 600 # 10 minutes; time between polling of buildbot.
# Some of our slower builders (llvm-next) are taking more
-# than 11 hours. So, increase this TIME_OUT to 12 hours.
-TIME_OUT = 43200 # Decide the build is dead or will never finish
+# than 12 hours. So, increase this TIME_OUT to 15 hours.
+TIME_OUT = 15 * 60 * 60 # Decide the build is dead or will never finish
class BuildbotTimeout(Exception):